


#include <allegro5/allegro.h>
#include <allegro5/allegro_image.h>
#include <allegro5/allegro_physfs.h>

#include <physfs.h>

#include <iostream>
using std::cout;
using std::endl;


int main(int argc, const char *argv[])
{
   ALLEGRO_DISPLAY *display;
   ALLEGRO_BITMAP *bmp;
//   ALLEGRO_FS_ENTRY *entry;
//   int i;

   if (!al_init()) {
      cout << "Failed to initialize allegro 5." << endl;
      return 1;
   }

   display = al_create_display(640, 480);
   if (!display) {
      cout << "Failed to create display." << endl;
      return 1;
   }

   al_init_image_addon();

   ALLEGRO_PATH *path = al_get_standard_path(ALLEGRO_RESOURCES_PATH);
   al_change_directory(al_path_cstr(path, '/'));  // change the working directory
   cout << "Current working directory is " << al_get_current_directory() << endl;
   al_destroy_path(path);

   if (!PHYSFS_init(argv[0])) {
      cout << "Failed to initialize PhysFS." << endl;
      return 1;
  }

   if (!PHYSFS_addToSearchPath("./data/test.zip", 1)) {
      cout << "Error adding ./data/test.zip to search path." << endl;
      return 1;
  }

   const char* file_name = "test.gif";
   al_set_physfs_file_interface();

   ALLEGRO_FILE *file;
   if (!(file = al_fopen(file_name, "r"))) {
      cout << "Could not open " << file_name << " for reading." << endl;
      return 1;
   }
   else {
      cout << "Opened file " << file_name << " for reading." << endl;
   }
   
   bmp = al_load_bitmap_f(file, ".gif");
   if (bmp) {
      cout << "Loaded " << file_name << " using al_load_bitmap_f." << endl;
      al_clear_to_color(al_map_rgba(0,0,0,0));
      al_draw_bitmap(bmp , 0 , 0 , 0);
      al_flip_display();
      al_rest(5.0);
      al_destroy_bitmap(bmp);
   }
   else {
      cout << "Failed to load " << file_name << " from ALLEGRO_FILE* using al_load_bitmap_f." << endl;
   }
   al_fclose(file);

   PHYSFS_deinit();
   return 0;
}
